@@ -1,5 +1,5 @@
 package Call::Haskell::ReadShow;
-use version; our $VERSION = version->declare('v0.1.0');
+use version; our $VERSION = version->declare('v0.1.1');
 use warnings;
 use strict;
 use v5.16;
@@ -81,7 +81,7 @@ sub show_algtype {
         show_maybe($data, $hs_type->{'TypeArgs'}->[0] );
     } else {
         # This is an unknown datatype. Give up
-         die "Type ".  $hs_type->{'TypeName'}. " not supported, please create a Perl counterpart using the Types module\n";
+         die "Type ".  $hs_type->{'TypeName'}. " not supported, please create a Perl counterpart using the Functional::Types module\n";
     }
 }
 
